summaryrefslogtreecommitdiffstats
path: root/src/java/com/jogamp/common/util/TaskBase.java
diff options
context:
space:
mode:
authorSven Gothel <[email protected]>2014-06-28 15:59:26 +0200
committerSven Gothel <[email protected]>2014-06-28 15:59:26 +0200
commiteb47aaba63e3b1bf55f274a0f338f1010a017ae4 (patch)
tree5e129e532519972457a8e71edec9d1410dd8c70f /src/java/com/jogamp/common/util/TaskBase.java
parent3bfc1e484ae247214d47f25fcc9b9da223f51fe1 (diff)
Fix 'typo' in messages: 'Catched' -> 'Caught'
Diffstat (limited to 'src/java/com/jogamp/common/util/TaskBase.java')
-rw-r--r--src/java/com/jogamp/common/util/TaskBase.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/java/com/jogamp/common/util/TaskBase.java b/src/java/com/jogamp/common/util/TaskBase.java
index f305bb1..db437f8 100644
--- a/src/java/com/jogamp/common/util/TaskBase.java
+++ b/src/java/com/jogamp/common/util/TaskBase.java
@@ -68,7 +68,7 @@ public abstract class TaskBase implements Runnable {
}
protected final String getExceptionOutIntro() {
- return catchExceptions ? "A catched" : "An uncatched";
+ return catchExceptions ? "A caught" : "An uncaught";
}
protected final void printSourceTrace() {
if( null != sourceStack && null != exceptionOut ) {
@@ -151,7 +151,7 @@ public abstract class TaskBase implements Runnable {
public final boolean hasWaiter() { return null != syncObject; }
/**
* @return A thrown exception while execution of the user action, if any and if catched
* @see #RunnableTask(Runnable, Object, boolean)
*/
public final Throwable getThrowable() { return runnableException; }
@@ -151,7 +151,7 @@ public abstract class TaskBase implements Runnable {
public final boolean hasWaiter() { return null != syncObject; }
/**
- * @return A thrown exception while execution of the user action, if any and if catched
+ * @return A thrown exception while execution of the user action, if any and if caught
* @see #RunnableTask(Runnable, Object, boolean)
*/